@@ -2,16 +2,18 @@
 # This file is part of SimpleGUITk - https://github.com/dholm/simpleguitk
 # See the file 'COPYING' for copying permission.
 
-import urllib
-
-from PIL import Image as PilImage
-from PIL import ImageTk
+import io
+try:
+    from urllib2 import urlopen
+except ImportError:
+    from urllib.request import urlopen
 
 
 class Image(object):
     def __init__(self, url):
-        image = urllib.urlretrieve(url)[0]
-        self._image = PilImage.open(image).convert('RGBA')
+        from PIL import Image as PilImage
+        image = urlopen(url).read()
+        self._image = PilImage.open(io.BytesIO(image)).convert('RGBA')
         self._versions = {}
 
     def get_width(self):
@@ -21,10 +23,14 @@ class Image(object):
         return self._image.size[1]
 
     def _get_tkimage(self, center, wh_src, wh_dst, rot):
+        from PIL import Image as PilImage
+        from PIL import ImageTk
         version = ','.join([str(center), str(wh_src), str(wh_dst), str(rot)])
         if version not in self._versions:
-            crop = (center[0] - wh_src[0] / 2, center[1] - wh_src[1] / 2,
-                    center[0] + wh_src[0] / 2, center[1] + wh_src[1] / 2)
+            crop = (int(center[0] - wh_src[0] // 2),
+                    int(center[1] - wh_src[1] // 2),
+                    int(center[0] + wh_src[0] // 2),
+                    int(center[1] + wh_src[1] // 2))
             image = self._image.crop([int(x) for x in crop])
             image = image.resize([int(x) for x in wh_dst],
                                  resample=PilImage.BILINEAR)
